#
# spec file for package grantlee5
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           grantlee5
Version:        5.1.0
Release:        3.4
Summary:        Qt string template library
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://grantlee.org/
Source:         http://downloads.grantlee.org/grantlee-%{version}.tar.gz
Source2:        baselibs.conf
# PATCH-FIX-UPSTREAM includes.diff -- since upstream doesn't provide a way to install to custom directory, we cheat!
Patch0:         includes.diff
BuildRequires:  cmake >= 3.1
BuildRequires:  doxygen
BuildRequires:  pkgconfig(Qt5Core) >= 5.3
BuildRequires:  pkgconfig(Qt5Gui) >= 5.3
BuildRequires:  pkgconfig(Qt5Script) >= 5.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Grantlee is a string template engine based on the Django template system and
written in Qt.

%package devel
Summary:        Include Files and Libraries Mandatory for Development with Grantlee
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       cmake >= 2.8.12
Requires:       pkgconfig(Qt5Core)
Requires:       pkgconfig(Qt5Gui)

%description devel
This package contains include files and libraries needed for development with
grantlee.

%prep
%setup -q -n grantlee-%{version}
%patch0 -p1

%build
%if "%{?_lib}" == "lib64"
SUFFIX="64"
%else
SUFFIX=""
%endif
mkdir -p build
pushd build
cmake .. \
  cmake -DCMAKE_BUILD_TYPE=None \\\
      -DCMAKE_C_FLAGS="%{optflags} -DNDEBUG" \\\
      -DCMAKE_CXX_FLAGS="%{optflags} -DNDEBUG" \\\
      -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-Bsymbolic-functions" \\\
      -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-Bsymbolic-functions" \\\
      -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-Bsymbolic-functions" \\\
      -DCMAKE_VERBOSE_MAKEFILE=ON \\\
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \\\
      -DBUILD_TESTS=OFF \\\
      -DLIB_SUFFIX=$SUFFIX ..

  make %{?_smp_mflags} VERBOSE=1
popd

%install
%makeinstall -C build

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGELOG COPYING* README*
%{_libdir}/libGrantlee_TextDocument.so.*
%{_libdir}/libGrantlee_Templates.so.*
%{_libdir}/grantlee/

%files devel
%defattr(-,root,root,-)
%doc AUTHORS CHANGELOG COPYING* README*
%{_includedir}/grantlee5/
%{_libdir}/libGrantlee_TextDocument.so
%{_libdir}/libGrantlee_Templates.so
%{_libdir}/cmake/Grantlee5/

%changelog
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * Implement advanced operators for the {%% if %%} tag
  * Use 'd' postfix for plugins built in debug mode
  * Use 'd' postfix for libraries built in debug mode by Visual Studio
  * Make it possible to build without QtScript and QtLinguistTools
  * Bump Grantlee CMake requirement to 3.1.
  * Bump Grantlee Qt requirement to 5.3.
* Wed Jan  7 2015 hrvoje.senjan@gmail.com
- Move away from using kf5-filesystem, only users of KDEInstallDirs
  should use it
* Wed Sep 24 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0 final:
  * No changelog since rc1 provided
* Mon Sep 22 2014 hrvoje.senjan@gmail.com
- Activate grantlee5 package, Qt5 based variant of the grantlee libs
- Update to 5.0.0~rc1
  * Drop Qt 4 build. Make Qt 5 a hard requirement.
  * Add a porting guide for users of old versions of Grantlee.
  * Drop custom handling of QObjects and containers in QVariant.
  * Drop old names 'grantlee_core' and 'grantlee_gui' in favor of
    'Templates' and 'Textdocument' respectively.
  * Rely on modern CMake features such as IMPORTED targets and
    usage requirements.
  * Bump Grantlee CMake requirement to 2.8.12.
  * Make the virtual Grantlee::Node::render method const.
  * Merge LocalizedFilesystemTemplateLoader
    into FilesystemTemplateLoader.
  * Remove typedefs for QSharedPointers from APIs.
- Bump miminal requied cmake version to 2.8.12
- Add includes.diff: since upstream doesn't provide a way to install
  to custom directory, we cheat!
- Add baselibs.conf
* Sat Nov 30 2013 hrvoje.senjan@gmail.com
- Update to 0.4.0
  * Bump Grantlee CMake requirement to 2.8.9.
  * Use the CMAKE_AUTOMOC feature in Grantlee.
  * Clean up all CMake code.
  * Fix memory leak when deleting a localized template loader.
  * Clean up C++ code in preparation for Qt 5.
  * Update jQuery version used in example to the latest release.
  * Add API for resolving variables to strings in QtScript.
  * Fix tests on ARM and other platforms which use float for qreal.
* Fri Nov  2 2012 cgiboudeaux@gmx.com
- Update to 0.3.0
  * Implement dictsort filter
  * Many new unit tests
  * Bug fixes and performance improvements
  * Roman numeral support in textdocument processing
* Sat Nov  5 2011 asterios.dramis@gmail.com
- Update to version 0.2.0:
  * Fix build on several platforms including mac, solaris and bsds.
  * Gather coverage data in release builds instead of debug builds.
  * Ensure that unit tests can be run and pass before installation.
  * Ensure that unit tests pass in multiple locales.
  * Fix several compiler warnings.
  * Add options for generating coverage data using testcocoon.
- Spec file updates:
  * Renamed License: to LGPL-2.1+.
  * Spec-cleaner run.
* Thu Jul  7 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Added Provides/Obsoletes for grantlee.
* Wed Jul  6 2011 asterios.dramis@gmail.com
- update to version 0.1.9
  * Port the lexer to a state machine based string parser.
  * Add feature to trim insignificant whitespace.
  * Build with stricter Qt flags QT_NO_KEYWORDS and QT_NO_CAST_FROM_BYTEARRAY.
  * Add example application for a html based templated application framework.
  * Add documentation and convenience functions for QObject and Q_PROPERTY
    introspection.
  * Modernise the CMake build system including creation of EXPORT targets and
    fixing of various cross-platform issues.
  * Add a componentized CPack packaging system for binary tarballs and windows
    install wizards.
  * Ability to use COMPONENTS argument to find_package with Grantlee.
  * Add a build target for generating code coverage information.
  * Platform fixes for MIPS, ARM and MinGW.
  * Add more documentation for example applications shipped with the Grantlee
    source.
  * Add the changelog for prior versions of Grantlee.
- Spec file updates:
  * Added lcov in BuildRequires:.
  * Changes based on openSUSE shared library packaging policy (added
    libgrantlee_core0 and libgrantlee_gui0 packages, removed grantlee
    package).
  * Minor other updates.
* Sun May 22 2011 asterios.dramis@gmail.com
- update to version 0.1.8
  * Add support for internationalization and localization features.
  * A new contacts/address book application.
  * Support for outputting QDate and QTime objects.
  * Automatic loading of QtScript based plugins.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPLv2.1+.
  * Updates in Group:, Summary: and %%description entries.
  * Removed libopenssl-devel from BuildRequires: (not needed).
  * Removed /sbin/ldconfig from devel package (not needed).
  * Minor other updates.
* Tue Dec 14 2010 wstephenson@novell.com
- Revert to 0.1.7 and tidy specfile
* Thu Oct 28 2010 tittiatcoke@gmail.com
- Went back to version 0.1.6 due to build issues. (Hanging build)
* Sun Oct 24 2010 wstephenson@novell.com
- update to version 0.1.7
  * Generic type support
  * Licensing fixes
  * Documentation fixes
* Thu Sep 30 2010 wstephenson@novell.com
- update to version 0.1.6
  * Fixed memory leaks
  * More strict casting from ascii
* Fri Sep 10 2010 tittiatcoke@gmail.com
- update to version 0.1.5
* Mon Jul 19 2010 freitag@novell.com
- update to version 0.1.3
* Mon Apr 19 2010 tittiatcoke@gmail.com
- Official release for version 0.1
* Fri Apr  9 2010 tittiatcoke@gmail.com
- Initial package
